@@ -1,7 +1,9 @@
+#!/bin/sh
+
+set -e
+
 # At least check we can execute the main binary
 # to catch missing python dependenies
-
-virt-install --help
-virt-xml --help
-virt-convert --help
-virt-clone --help
+for p in install xml convert clone; do
+    virt-$p --help
+done
